package demo

import (
	"crypto/md5"
	"fmt"
	"io"
	"strconv"
	"time"

	"../adapay/member"
	"../adapay/utils"
)

/**
创建用户对象
文档说明：https://docs.adapay.tech/api/trade.html#id25
*/
func TestMemberCreat() {
	params := make(map[string]interface{})

	crutime := time.Now().Unix()
	h := md5.New()
	io.WriteString(h, strconv.FormatInt(crutime, 10))
	member_id := fmt.Sprintf("%x", h.Sum(nil))

	params["member_id"] = member_id
	params["app_id"] = "app_7d87c043-aae3-4357-9b2c-269349a980d6"
	params["location"] = "上海"
	params["email"] = "123@123.com"
	params["gender"] = "MALE"
	params["tel_no"] = "18016612949"
	params["nickname"] = "Haki"

	data, apiError, err := member.Create(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] MemberCreat Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] MemberCreat Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] MemberCreat Success ---> ", data)
}

/**
查询用户对象
文档说明：https://docs.adapay.tech/api/trade.html#id27
*/
func TestMemberQuery() {
	params := make(map[string]interface{})

	params["member_id"] = "d44610d38731c6d4153b2d567fa52270"
	params["app_id"] = "app_7d87c043-aae3-4357-9b2c-269349a980d6"

	data, apiError, err := member.Query(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] MemberQuery Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] MemberQuery Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] MemberQuery Success ---> ", data)
}

/**
更新用户对象
文档说明：https://docs.adapay.tech/api/trade.html#id26
*/
func TestMemberUpdate() {
	params := make(map[string]interface{})

	params["member_id"] = "d44610d38731c6d4153b2d567fa52270"
	params["app_id"] = "app_7d87c043-aae3-4357-9b2c-269349a980d6"
	params["location"] = "上海"
	params["email"] = "123@123.com"
	params["gender"] = "MALE"
	params["tel_no"] = "18016612949"
	params["nickname"] = "Haki..."

	data, apiError, err := member.Update(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] MemberCreat Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] MemberCreat Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] MemberCreat Success ---> ", data)
}

/**
查询用户对象列表
文档说明：https://docs.adapay.tech/api/trade.html#id28
*/
func TestMemberQueryList() {
	params := make(map[string]interface{})

	params["app_id"] = "app_7d87c043-aae3-4357-9b2c-269349a980d6"
	// params["page_index"] = ""
	// params["page_size"] = ""
	// params["created_gte"] = ""
	// params["created_lte"] = ""

	data, apiError, err := member.QueryList(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] MemberQuery Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] MemberQuery Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] MemberQuery Success ---> ", data)
}
