package demo

import (
	"../adapay/payment"
	"../adapay/utils"
)

/**
创建一笔新 Payment
文档说明：https://docs.adapay.tech/api/trade.html#id3
*/
func DoPaymentCreate() {
	createPaymentParams := make(map[string]interface{})

	// 填写请求参数
	createPaymentParams["order_no"] = "Your systom order id"        // TODO
	createPaymentParams["app_id"] = "Your Appid"                    // TODO 请至 Adapay 控台创建您的应用，并获取相印 Appid
	createPaymentParams["pay_channel"] = "alipay"                   // TODO
	createPaymentParams["pay_amt"] = "0.01"                         // TODO
	createPaymentParams["goods_title"] = "Your payment goods_title" // TODO
	createPaymentParams["goods_desc"] = "Your payment goods_desc"   // TODO
	createPaymentParams["currency"] = "cny"                         // TODO
	// TODO
	// @Notice 	常规商户推荐使用 adapay.notify 下功能，来注册和监听自身的异步消息
	// 			下属多商户的渠道服务商可在此处传入异步消息接收 url，接收 Adapay 系统发来数据，统一处理下属多商户的相关消息
	createPaymentParams["notify_url"] = "Your notify url"

	/*
		@Notice
		具体参数说明以及更多参数选项，请参考 Adapay API 文档 https://docs.adapay.tech/api/trade.html#id3
	*/

	// 调用 SDK 方法获取结果（同步返回 payment 创建结果，交易结果异步通知）
	data, apiError, err := payment.Create(createPaymentParams, "merch_no_0000001")

	/*
		@Notice
		1. 常规调用时，sdk 将使用 config.init 方法设置的商户配置信息，参考 commonDemo.DoConfigInit
		2. 下属多商户的渠道服务商在调用时，可指定商户配置文件，以便使用对应商户的角色进行交易
			示例：payment.Create(createPaymentParams, "merchConfigId")
			其中 merchConfigId 为初始化多商户配置时设置的 ID，参考 commonDemo.DoMultiConfigInit
	*/

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] DoPaymentCreate Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] DoPaymentCreate Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO Payment 创建成功处理
	*/

	utils.Println("[DEMO] DoPaymentCreate Success ---> Payment ---> ", data)

}

/**
查询一笔已存在的 Payment
文档说明：https://docs.adapay.tech/api/trade.html#id7
*/
func DoPaymentQuery() {
	queryPaymentId := "Your ID" // TODO

	// 调用 SDK 方法获取结果（同步）
	data, apiError, err := payment.Query(queryPaymentId, "merch_no_0000001")

	/*
		@Notice
		1. 常规调用时，sdk 将使用 config.init 方法设置的商户配置信息，参考 commonDemo.DoConfigInit
		2. 下属多商户的渠道服务商在调用时，可指定商户配置文件，以便使用对应商户的角色进行交易
			示例：payment.Query(queryPaymentId, "merchConfigId")
			其中 merchConfigId 为初始化多商户配置时设置的 ID，参考 commonDemo.DoMultiConfigInit
	*/

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] DoPaymentQuery Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] DoPaymentQuery Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO Payment 查询成功处理
	*/

	utils.Println("[DEMO] DoPaymentQuery Success ---> Payment ---> ", data)

}

/**
关单
文档说明：https://docs.adapay.tech/api/trade.html#id11
*/
func DoPaymentClose() {
	closePaymentParams := make(map[string]interface{})

	// 填写请求参数
	closePaymentParams["payment_id"] = "Your ID"               // TODO
	closePaymentParams["reason"] = "Your close payment reason" // TODO
	closePaymentParams["expend"] = "Expend data"               // TODO
	// TODO
	// @Notice 	常规商户推荐使用 adapay.notify 下功能，来注册和监听自身的异步消息
	// 			下属多商户的渠道服务商可在此处传入异步消息接收 url，接收 Adapay 系统发来数据，统一处理下属多商户的相关消息
	closePaymentParams["notify_url"] = ""

	// 调用 SDK 方法发起请求（同步响应受理情况，异步返回结果）
	data, apiError, err := payment.Close(closePaymentParams, "merch_no_0000001")

	/*
		@Notice
		1. 常规调用时，sdk 将使用 config.init 方法设置的商户配置信息，参考 commonDemo.DoConfigInit
		2. 下属多商户的渠道服务商在调用时，可指定商户配置文件，以便使用对应商户的角色进行交易
			示例：payment.Close(closePaymentParams, "merchConfigId")
			其中 merchConfigId 为初始化多商户配置时设置的 ID，参考 commonDemo.DoMultiConfigInit
	*/

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] DoPaymentClose Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] DoPaymentClose Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO Payment 成功发起关单，后续查询或异步处理关单结果
	*/

	utils.Println("[DEMO] DoPaymentClose Success ---> Payment ---> ", data)
}

/**
创建支付确认对象
文档说明：https://docs.adapay.tech/api/trade.html#id39
*/
func TestCreateConfirm() {
	params := make(map[string]interface{})
	// 填写请求参数
	params["payment_id"] = ""
	params["order_no"] = ""
	params["confirm_amt"] = ""
	params["description"] = ""
	params["div_members"] = ""

	// 调用 SDK 方法发起请求（同步响应受理情况，异步返回结果）
	data, apiError, err := payment.CreateConfirm(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] CreateConfirm Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] CreateConfirm Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] CreateConfirm Success ---> ", data)
}

/**
查询支付确认对象
文档说明：https://docs.adapay.tech/api/trade.html#id43
*/
func TestQueryConfirm() {
	params := make(map[string]interface{})

	params["payment_confirm_id"] = ""

	data, apiError, err := payment.QueryConfirm(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] QueryConfirm Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] QueryConfirm Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] QueryConfirm Success ---> ", data)
}

/**
查询支付确认对象列表
文档说明：https://docs.adapay.tech/api/trade.html#id47
*/
func TestQueryConfirmList() {
	params := make(map[string]interface{})

	params["app_id"] = ""
	params["payment_id"] = ""
	params["page_index"] = ""
	params["page_size"] = ""
	params["created_gte"] = ""
	params["created_lte"] = ""

	data, apiError, err := payment.QueryConfirmList(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] QueryConfirmList Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] QueryConfirmList Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] QueryConfirmList Success ---> ", data)
}

/**
创建支付撤销对象
文档说明：https://docs.adapay.tech/api/trade.html#id53
*/
func TestCreateReverse() {
	params := make(map[string]interface{})

	params["payment_id"] = ""
	params["app_id"] = ""
	params["order_no"] = ""
	params["notify_url"] = ""
	params["reverse_amt"] = ""
	// 非必填
	// params["reason"]
	// params["expand"]
	// params["device_info"]

	data, apiError, err := payment.CreateReverse(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] CreateReverse Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] CreateReverse Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] CreateReverse Success ---> ", data)
}

/**
查询支付撤销对象
文档说明：https://docs.adapay.tech/api/trade.html#id57
*/
func TestQueryReverse() {
	params := make(map[string]interface{})

	params["reverse_id"] = ""

	data, apiError, err := payment.QueryReverse(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] QueryReverse Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] QueryReverse Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] QueryReverse Success ---> ", data)
}

/**
查询支付撤销对象列表
文档说明：https://docs.adapay.tech/api/trade.html#id61
*/
func TestQueryReverseList() {
	params := make(map[string]interface{})

	params["app_id"] = ""
	params["payment_id"] = ""
	params["page_index"] = ""
	params["page_size"] = ""
	params["created_gte"] = ""
	params["created_lte"] = ""

	data, apiError, err := payment.QueryReverseList(params, "merch_no_0000001")

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] QueryReverseList Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] QueryReverseList Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO 成功处理
	*/

	utils.Println("[DEMO] QueryReverseList Success ---> ", data)
}
