package demo

import (
	"../adapay/refund"
	"../adapay/utils"
)

/**
创建一笔新 Refund
文档说明：https://docs.adapay.tech/api/trade.html#id16
*/
func DoRefundCreate() {
	createRefundParams := make(map[string]interface{})

	// 填写请求参数
	createRefundParams["payment_id"] = "Your Refund Pament id"     // TODO
	createRefundParams["refund_order_no"] = "Your system order id" // TODO
	createRefundParams["refund_amt"] = "0.01"                      // TODO
	// TODO
	// @Notice 	常规商户推荐使用 adapay.notify 下功能，来注册和监听自身的异步消息
	// 			下属多商户的渠道服务商可在此处传入异步消息接收 url，接收 Adapay 系统发来数据，统一处理下属多商户的相关消息
	createRefundParams["notify_url"] = "Your notify url"

	/*
		@Notice
		具体参数说明以及更多参数选项，请参考 Adapay API 文档 https://docs.adapay.tech/api/trade.html#id16
	*/

	// 调用 SDK 方法获取结果（同步返回 refund 创建结果，退款结果异步通知）
	data, apiError, err := refund.Create(createRefundParams, "merch_no_0000001")

	/*
		@Notice
		1. 常规调用时，sdk 将使用 config.init 方法设置的商户配置信息，参考 commonDemo.DoConfigInit
		2. 下属多商户的渠道服务商在调用时，可指定商户配置文件，以便使用对应商户的角色进行交易
			示例：refund.Create(createRefundParams, "merchConfigId")
			其中 merchConfigId 为初始化多商户配置时设置的 ID，参考 commonDemo.DoMultiConfigInit
	*/

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] DoRefundCreate Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] DoRefundCreate Failed ---> Response ---> ", apiError)
		return
	}

	/*
		TODO Refund 创建成功处理
	*/

	utils.Println("[DEMO] DoRefundCreate Success ---> Refund ---> ", data)

}

/**
查询一笔已存在的 Refund
文档说明：https://docs.adapay.tech/api/trade.html#id19
*/
func DoRefundQuery() {
	queryRefundParams := make(map[string]interface{})

	// 填写请求参数
	queryRefundParams["refund_id"] = "Your Refund id" // TODO
	//queryRefundParams["payment_id"] = "Your Refund Pament id"	// TODO

	/*
		@Notice
		refund_id 和 payment_id 为必填二选一参数
	*/

	// 调用 SDK 方法获取同步结果
	data, apiError, err := refund.Query(queryRefundParams, "merch_no_0000001")

	/*
		@Notice
		1. 常规调用时，sdk 将使用 config.init 方法设置的商户配置信息，参考 commonDemo.DoConfigInit
		2. 下属多商户的渠道服务商在调用时，可指定商户配置文件，以便使用对应商户的角色进行交易
			示例：refund.Create(createRefundParams, "merchConfigId")
			其中 merchConfigId 为初始化多商户配置时设置的 ID，参考 commonDemo.DoMultiConfigInit
	*/

	// 异常处理
	if err != nil { // 网络或本应用异常
		utils.Println("[DEMO] DoRefundQuery Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[DEMO] DoRefundQuery Failed ---> Response ---> ", apiError)
		return
	}

	utils.Println("[DEMO] DoRefundQuery Success ---> Response Data ---> ", data)

	// TODO 成功获取到 Refund 记录的处理, 以下代码块为示例代码
	{
		var refundsResult []map[string]interface{}
		switch data["refunds"].(type) {
		case []map[string]interface{}:
			refundsResult = data["refunds"].([]map[string]interface{})
		}

		/*
			@Notice
			refund 返回数据为集合，当请求参数为 payment_id 时，返回该 payment 下对应的所有退款记录
			当请求参数为 refund_id 时，返回的集合中仅有 id 对应那条 refund 记录
		*/

		utils.Println("[DEMO] DoRefundQuery Success ---> Response Refunds ---> ", refundsResult)
	}
}
