package demo

import (
	"../adapay/settleAccount"
	"../adapay/utils"
)

/**
创建结算账户对象
文档说明：https://docs.adapay.tech/api/trade.html#id33
*/
func DoSettleAccountCreate() {
	// 创建请求对象
	createSettleParam := make(map[string]interface{})
	accountInfo := make(map[string]interface{})

	accountInfo["card_id"] = "user's card_id"               // 银行卡号
	accountInfo["card_name"] = "user's card_name"           //银行账户名称
	accountInfo["cert_id"] = "user's cert_id"               // 证件号
	accountInfo["cert_type"] = "user's cert_type"           // 证件类型，仅支持：身份证（00）
	accountInfo["tel_no"] = "user's tel_no"                 //手机号
	accountInfo["bank_code"] = "user's bank_code"           //详见 api 网站上提供的银行代码文档
	accountInfo["bank_acct_type"] = "user's bank_acct_type" //银行账户类型：1-对公；2-对私
	accountInfo["prov_code"] = "bankcard's prov_code"       // 省份 （省市区编码）
	accountInfo["area_code"] = "bankcard's s area_code"     // 地区

	createSettleParam["member_id"] = "user's member_id" // 商户用户对象 id
	createSettleParam["app_id"] = "your app_id"         // 对应 app 对象的 id
	createSettleParam["channel"] = "bank_account"       // 目前仅支持：bank_account（银行卡）
	createSettleParam["account_info"] = accountInfo

	data, apiError, err := settleAccount.Create(createSettleParam, "merch_no_0000001") // 将银行卡账号对象放入创建结算账号对象

	// 网络或本应用异常
	if err != nil {
		// 在此处理网络或本应用异常
		utils.Println("[DoSettleAccountCreate] Failed ---> " + err.Error())
		return
	}

	// adapay 服务返回异常
	if apiError != nil {
		// 在此处理adapay 服务返回异常
		utils.Println("[DoSettleAccountCreate] Failed ---> Response ---> ", apiError)
		return
	}

	// 处理成功后逻辑
	utils.Println("[DoSettleAccountCreate] Success ---> data: ", data)

}

/**
查询结算账户对象
文档说明：https://docs.adapay.tech/api/trade.html#id34
*/
func DoSettleAccountQuery() {
	// 创建请求对象
	querySettleAccountParam := make(map[string]interface{})

	querySettleAccountParam["settle_account_id"] = "user's settle_account_id" //由 Adapay 生成的结算账户对象 id
	querySettleAccountParam["member_id"] = "user's member_id"                 //商户用户对象 id
	querySettleAccountParam["app_id"] = "your app_id"                         //对应 app 对象的 id

	data, apiError, err := settleAccount.Query(querySettleAccountParam, "merch_no_0000001")

	// 网络或本应用异常
	if err != nil {
		// 在此处理网络或本应用异常
		utils.Println("[DoSettleAccountQuery] Failed ---> " + err.Error())
		return
	}

	// adapay 服务返回异常
	if apiError != nil {
		// 在此处理adapay 服务返回异常
		utils.Println("[DoSettleAccountQuery] Failed ---> Response ---> ", apiError)
		return
	}

	// 处理成功后逻辑
	utils.Println("[DoSettleAccountQuery] Success ---> data: ", data)

}

/**
查询结算明细列表
文档说明：https://docs.adapay.tech/api/trade.html#id36
*/
func DoSettleAccountQueryDetails() {
	// 创建请求对象
	querySettleDetailParam := make(map[string]interface{})

	querySettleDetailParam["settle_account_id"] = "user's settle_account_id" //由Adapay生成的结算账户对象id，若查询商户本身时，可以为空
	querySettleDetailParam["member_id"] = "user's member_id"                 //商户用户对象 id，64 位以内，必须是英文、数字或者下划线，若查询商户本身时，传入值0
	querySettleDetailParam["app_id"] = "your app_id"                         //对应 app 对象的 id
	querySettleDetailParam["begin_date"] = "yyyyMMdd"                        //结算起始日期，格式为 yyyyMMdd
	querySettleDetailParam["end_date"] = "yyyyMMdd"                          //结算结束日期，格式为 yyyyMMdd，日期间隔必须小于等于31天

	data, apiError, err := settleAccount.Delete(querySettleDetailParam, "merch_no_0000001")

	// 网络或本应用异常
	if err != nil {
		// 在此处理网络或本应用异常
		utils.Println("[DoSettleAccountQueryDetails] Failed ---> " + err.Error())
		return
	}

	// adapay 服务返回异常
	if apiError != nil {
		// 在此处理adapay 服务返回异常
		utils.Println("[DoSettleAccountQueryDetails] Failed ---> Response ---> ", apiError)
		return
	}

	// 处理成功后逻辑
	utils.Println("[DoSettleAccountQueryDetails] Success ---> data: ", data)
}

/**
删除结算账户对象
文档说明：https://docs.adapay.tech/api/trade.html#id35
*/
func DoSettleAccountDelete() {
	// 创建请求对象
	deleteSettleParam := make(map[string]interface{})

	deleteSettleParam["settle_account_id"] = "user's settle_account_id" //由 Adapay 生成的结算账户对象 id
	deleteSettleParam["member_id"] = "user's member_id"                 //商户用户对象 id
	deleteSettleParam["app_id"] = "your app_id"                         //对应 app 对象的 id

	data, apiError, err := settleAccount.Delete(deleteSettleParam, "merch_no_0000001")

	// 网络或本应用异常
	if err != nil {
		// 在此处理网络或本应用异常
		utils.Println("[DoSettleAccountDelete] Failed ---> " + err.Error())
		return
	}

	// adapay 服务返回异常
	if apiError != nil {
		// 在此处理adapay 服务返回异常
		utils.Println("[DoSettleAccountDelete] Failed ---> Response ---> ", apiError)
		return
	}

	// 处理成功后逻辑
	utils.Println("[DoSettleAccountDelete] Success ---> data: ", data)
}

func DoSettleAccountModify() {
	param := make(map[string]interface{})
	param["settle_account_id"] = "0023056905335360"
	param["member_id"] = "user_test_10001"
	param["app_id"] = "app_7d87c043-aae3-4357-9b2c-269349a980d6"
	param["min_amt"] = ""

	data, apiError, err := settleAccount.Modify(param, "msc_correct")

	if err != nil { // 网络或本应用异常
		utils.Println("[testSettleDelete] Failed ---> " + err.Error())
		return
	}
	if apiError != nil { // adapay 服务返回异常
		utils.Println("[testSettleDelete] Failed ---> Response ---> ", apiError)
		return
	}

	utils.Println("[testSettleDelete] Success ---> data: ", data)
}
