package config

import (
	"encoding/json"
	"errors"
	"fmt"
	"io/ioutil"

	"../gloable"
	. "../struts"
	"../utils"
)

func Init(configPath string) {
	msc, err := readMerchConfig(configPath)
	if err != nil {
		utils.Println("Adapay init failed ---> ", err.Error())
		return
	}
	if msc == nil {
		utils.Println("Adapay init failed...")
		return
	}

	gloable.GDefaultMerchSysConfig = *msc
}

func InitMulti(multiMarchConfigPaths map[string]string) {
	for id, path := range multiMarchConfigPaths {
		if id == "" {
			utils.Println(
				fmt.Sprintf("InitMutli Read Config File Failed ---> id: %s,  path: %s",
					id, path))
			continue
		}

		msc, err := readMerchConfig(path)
		if err != nil || msc == nil || msc.IsEmpty() {
			utils.Println(
				fmt.Sprintf("InitMutli Read Config File Failed ---> id: %s,  path: %s",
					id, path))
			continue
		}

		gloable.GMultiMerchSysConfigs[id] = *msc
	}
}

func readMerchConfig(configPath string) (*MerchSysConfig, error) {

	data, err := ioutil.ReadFile(configPath)
	if err != nil {
		return nil, errors.New(
			fmt.Sprintf("ReadMerchConfig Read Config File Failed ---> path: %s", configPath))
	}


	tmpMsc := MerchSysConfig{}
	jsonError := json.Unmarshal(data, &tmpMsc)
	if jsonError != nil {
		return nil, errors.New(
			fmt.Sprintf("ReadMerchConfig Read Config File Failed ---> path: %s", configPath))
	}


	if tmpMsc.ApiKeyLive == "" || tmpMsc.ApiKeyTest == "" ||
		tmpMsc.RspPubKey == "" || tmpMsc.RspPriKey == "" {
		return nil, errors.New(
			fmt.Sprintf("ReadMerchConfig Read Config File Failed ---> path: %s", configPath))
	}

	return &tmpMsc, nil
}
