package payment

import (
	"errors"
	"fmt"
	"strings"

	. "../gloable"
	. "../struts"
	"../utils"
)

func Create(reqParam map[string]interface{}, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	data := make(map[string]interface{})
	reqUrl := BASE_URL + PAYMENT_CREATE


	var msc MerchSysConfig
	if multiMerchConfigId == nil {
		msc = GDefaultMerchSysConfig
	} else {
		msc = utils.GetMerchSysConfig(multiMerchConfigId[0])
	}


	resp, err := utils.DoPostReq(reqUrl, reqParam, msc)
	if err != nil {
		return data, nil, errors.New(fmt.Sprintf("网络异常 ==> %s", err.Error()))
	}


	data, apiErr, err := utils.HandleResponse(resp, msc)
	if apiErr != nil || err != nil {
		return data, apiErr, err
	}


	if data["id"] == "" {
		return data, nil, errors.New(fmt.Sprintf("Payment 返回数据异常 ==> %s", data))
	}

	return data, nil, nil
}

func Query(paymentId string, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	data := make(map[string]interface{})

	reqUrl := BASE_URL + strings.Replace(PAYMENT_QUERY, "{payment_id}", paymentId, -1)
	reqParam := map[string]interface{}{
		"payment_id": paymentId,
	}


	var msc MerchSysConfig
	if multiMerchConfigId == nil {
		msc = GDefaultMerchSysConfig
	} else {
		msc = utils.GetMerchSysConfig(multiMerchConfigId[0])
	}


	resp, err := utils.DoGetReq(reqUrl, reqParam, msc)
	if err != nil {
		return data, nil, errors.New(fmt.Sprintf("网络异常 ==> %s", err.Error()))
	}


	data, apiErr, err := utils.HandleResponse(resp, msc)
	if apiErr != nil || err != nil {
		return data, apiErr, err
	}


	if data["id"] == "" {
		return data, nil, errors.New(fmt.Sprintf("Payment 返回数据异常 ==> %s", data))
	}

	return data, nil, nil
}

func Close(reqParam map[string]interface{}, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	data := make(map[string]interface{})

	if reqParam["payment_id"] == nil || reqParam["payment_id"] == "" {
		return data, nil, errors.New(fmt.Sprintf("请求参数错误 ==> %s", "payment_id"))
	}

	reqUrl := BASE_URL +
		strings.Replace(PAYMENT_CLOSE, "{payment_id}", utils.ToString(reqParam["payment_id"]), -1)


	var msc MerchSysConfig
	if multiMerchConfigId == nil {
		msc = GDefaultMerchSysConfig
	} else {
		msc = utils.GetMerchSysConfig(multiMerchConfigId[0])
	}


	resp, err := utils.DoPostReq(reqUrl, reqParam, msc)
	if err != nil {
		return data, nil, errors.New(fmt.Sprintf("网络异常 ==> %s", err.Error()))
	}


	data, apiErr, err := utils.HandleResponse(resp, msc)
	if apiErr != nil || err != nil {
		return data, apiErr, err
	}

	return data, nil, nil
}

func CreateConfirm(reqParam map[string]interface{}, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	reqUrl := BASE_URL + PAYMENT_CONFIRM
	return utils.RequestAdaPay(reqUrl, utils.POST, reqParam, multiMerchConfigId...)
}

func QueryConfirm(reqParam map[string]interface{}, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	reqUrl := BASE_URL + strings.Replace(PAYMENT_QUERY_CONFIRM, "{payment_confirm_id}", utils.ToString(reqParam["payment_confirm_id"]), -1)
	return utils.RequestAdaPay(reqUrl, utils.GET, reqParam, multiMerchConfigId...)
}

func QueryConfirmList(reqParam map[string]interface{}, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	reqUrl := BASE_URL + PAYMENT_QUERY_CONFIRM_LIST
	return utils.RequestAdaPay(reqUrl, utils.GET, reqParam, multiMerchConfigId...)
}

func CreateReverse(reqParam map[string]interface{}, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	reqUrl := BASE_URL + PAYMENT_REVERSE
	return utils.RequestAdaPay(reqUrl, utils.POST, reqParam, multiMerchConfigId...)
}

func QueryReverse(reqParam map[string]interface{}, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	reqUrl := BASE_URL + strings.Replace(PAYMENT_QUERY_REVERSE, "{reverse_id}", utils.ToString(reqParam["reverse_id"]), -1)
	return utils.RequestAdaPay(reqUrl, utils.GET, reqParam, multiMerchConfigId...)
}

func QueryReverseList(reqParam map[string]interface{}, multiMerchConfigId ...string) (map[string]interface{}, *ApiError, error) {
	reqUrl := BASE_URL + PAYMENT_QUERY_REVERSE_LIST
	return utils.RequestAdaPay(reqUrl, utils.GET, reqParam, multiMerchConfigId...)
}
